@@ -11,6 +11,7 @@ from artify import nexus
 from artify import deploy
 from artify import syncrepo
 from artify import change_version
+from artify import generate_file
 
 debug = 0;
 
@@ -53,6 +54,9 @@ branch = ''
 commit_message = ''
 # Variables - sync repository
 
+# Variables - create file
+filename_gen = ''
+# Variables - create file
 
 def main(argv):  
     print("Copyright \N{COPYRIGHT SIGN} 2020 Stewartium ::: artify v{}\n".format(__version__))
@@ -87,14 +91,16 @@ def main(argv):
     global branch
     global commit_message
     
-    debug = 0
+    # Variables - generate file
+    global filename_gen
    
     try:
         opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=",
                                                 "type=", "archtype=",
-                                                "message=", "branch="
+                                                "message=", "branch=",
+                                                "debug"
                                                ])
     except getopt.GetoptError:
         print('Invalid syntax')
@@ -160,6 +166,8 @@ def main(argv):
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
                 print('python -m artify --help syncrepo     Help on how to commit and push code to repository')
                 print('python -m artify --help deltav      Help on how to change version number')
+        elif opt == "--debug":
+            debug = 1
         elif opt in ("-c", "--command"):
             action = arg
             if action == '':
@@ -181,6 +189,10 @@ def main(argv):
             elif action == 'deploy':
                 with open(arg, "rb") as manifest_file:
                     encoded_string = base64.b64encode(manifest_file.read())
+            elif action == 'create':
+                # Generate file START
+                filename_gen = arg
+                # Generate file END
             else:
                 print("Invalid command specified: param: -f")
                      
@@ -288,12 +300,20 @@ def main(argv):
         else:
             print("Invalid nexus format entered")
             
-    if action == 'deltav':
+    elif action == 'deltav':
         change_version.modify_version()
-    if action == 'syncrepo':
+    elif action == 'syncrepo':
         syncrepo.commit_push_changes(commit_message)
-    if action == 'deploy':
+    elif action == 'deploy':
         deploy.deploy_app_awx()
+    elif action == 'create':
+        generate_file.generator(filename_gen)
+    elif action == '':
+        print("Invalid action specified")
+        return sys.exit(2)
+    else:
+        print("Action not supported")
+        return sys.exit(2)
     
     
 if __name__ == "__main__":
